==> CGAL-6.0-doc_html.tar.xz: doc_html/Manual/devman_create_and_use_a_cmakelist.js <==
var devman_create_and_use_a_cmakelist =
[
    [ "Linking with CGAL", "devman_create_and_use_a_cmakelist.html#seclink", null ],
    [ "Minimal Example Using Qt6", "devman_create_and_use_a_cmakelist.html#secexample", [
      [ "CMakeLists.txt", "devman_create_and_use_a_cmakelist.html#subcmake", null ],
      [ "draw_surface_mesh.cpp", "devman_create_and_use_a_cmakelist.html#subexcpp", null ]
    ] ],
    [ "Compilers and Third Party Dependencies", "thirdparty.html", [
      [ "Supported Compilers", "thirdparty.html#seccompilers", null ],
      [ "CMake", "thirdparty.html#seccmake", null ],
      [ "Essential Third Party Libraries", "thirdparty.html#secessential3rdpartysoftware", [
        [ "Standard Template Library (STL)", "thirdparty.html#thirdpartystl", null ],
        [ "Boost", "thirdparty.html#thirdpartyBoost", null ],
        [ "Multi Precision Number Type Library", "thirdparty.html#thirdpartyMP", null ]
      ] ],
      [ "Optional Third Party Libraries", "thirdparty.html#secoptional3rdpartysoftware", [
        [ "Qt6", "thirdparty.html#thirdpartyQt", null ],
        [ "Eigen", "thirdparty.html#thirdpartyEigen", null ],
        [ "OpenGR", "thirdparty.html#thirdpartyOpenGR", null ],
        [ "PointMatcher", "thirdparty.html#thirdpartylibpointmatcher", null ],
        [ "LEDA", "thirdparty.html#thirdpartyLeda", null ],
        [ "Multiple Precision Floating-point Interval (MPFI)", "thirdparty.html#thirdpartyMPFI", null ],
        [ "RS and RS3", "thirdparty.html#thirdpartyRS3", null ],
        [ "NTL", "thirdparty.html#thirdpartyNTL", null ],
        [ "ESBTL", "thirdparty.html#thirdpartyESBTL", null ],
        [ "Intel TBB", "thirdparty.html#thirdpartyTBB", null ],
        [ "LASlib", "thirdparty.html#thirdpartyLASlib", null ],
        [ "OpenCV", "thirdparty.html#thirdpartyOpenCV", null ],
        [ "METIS", "thirdparty.html#thirdpartyMETIS", null ],
        [ "zlib", "thirdparty.html#thirdpartyzlib", null ],
        [ "Ceres Solver", "thirdparty.html#thirdpartyCeres", null ],
        [ "GLPK", "thirdparty.html#thirdpartyGLPK", null ],
        [ "SCIP", "thirdparty.html#thirdpartySCIP", null ],
        [ "OSQP", "thirdparty.html#thirdpartyOSQP", null ]
      ] ]
    ] ]
];

==> CGAL-6.0.3-doc_html.tar.xz: doc_html/Manual/devman_create_and_use_a_cmakelist.js <==
var devman_create_and_use_a_cmakelist =
[
    [ "Linking with CGAL", "devman_create_and_use_a_cmakelist.html#seclink", null ],
    [ "Minimal Example Using Qt6", "devman_create_and_use_a_cmakelist.html#secexample", [
      [ "CMakeLists.txt", "devman_create_and_use_a_cmakelist.html#subcmake", null ],
      [ "draw_surface_mesh.cpp", "devman_create_and_use_a_cmakelist.html#subexcpp", null ]
    ] ],
    [ "Compilers and Third Party Dependencies", "thirdparty.html", [
      [ "Supported Compilers", "thirdparty.html#seccompilers", null ],
      [ "CMake", "thirdparty.html#seccmake", null ],
      [ "Essential Third Party Libraries", "thirdparty.html#secessential3rdpartysoftware", [
        [ "Standard Template Library (STL)", "thirdparty.html#thirdpartystl", null ],
        [ "Boost", "thirdparty.html#thirdpartyBoost", null ],
        [ "Multi Precision Number Type Library", "thirdparty.html#thirdpartyMP", null ]
      ] ],
      [ "Optional Third Party Libraries", "thirdparty.html#secoptional3rdpartysoftware", [
        [ "Qt6", "thirdparty.html#thirdpartyQt", null ],
        [ "Eigen", "thirdparty.html#thirdpartyEigen", null ],
        [ "OpenGR", "thirdparty.html#thirdpartyOpenGR", null ],
        [ "PointMatcher", "thirdparty.html#thirdpartylibpointmatcher", null ],
        [ "Multiple Precision Floating-point Interval (MPFI)", "thirdparty.html#thirdpartyMPFI", null ],
        [ "RS and RS3", "thirdparty.html#thirdpartyRS3", null ],
        [ "NTL", "thirdparty.html#thirdpartyNTL", null ],
        [ "ESBTL", "thirdparty.html#thirdpartyESBTL", null ],
        [ "Intel TBB", "thirdparty.html#thirdpartyTBB", null ],
        [ "LASlib", "thirdparty.html#thirdpartyLASlib", null ],
        [ "OpenCV", "thirdparty.html#thirdpartyOpenCV", null ],
        [ "SuiteSparse", "thirdparty.html#thirdpartySuiteSparse", null ],
        [ "METIS", "thirdparty.html#thirdpartyMETIS", null ],
        [ "zlib", "thirdparty.html#thirdpartyzlib", null ],
        [ "Ceres Solver", "thirdparty.html#thirdpartyCeres", null ],
        [ "GLPK", "thirdparty.html#thirdpartyGLPK", null ],
        [ "SCIP", "thirdparty.html#thirdpartySCIP", null ],
        [ "OSQP", "thirdparty.html#thirdpartyOSQP", null ]
      ] ]
    ] ]
];
